@@ -1,17 +1,18 @@
 # Encoding: utf-8
 import sys
-from .dispersions.dispersions import *
+
+from .dispersions import *
 from .dispersions.base_dispersion import *
 from .experiment import Experiment
+from .importer.nexus import *
+from .importer.spectraray import *
 from .materials import *
-from .math import *
+from .materials_db import *
 from .result import Result, ResultList
 from .solver2x2 import Solver2x2
 from .solver4x4 import *
 from .structure import *
 from .utils import *
-from .spectraray import *
-from .materials_db import *
 
 if sys.version_info.major >= 3 and sys.version_info.minor > 7:
     from importlib.metadata import PackageNotFoundError, version
