@@ -1,10 +1,26 @@
 # Encoding: utf-8
+r"""The experiment class defines the external conditions of the sample.
+
+It requires a Structure to evaluate and includes the information about
+the incident light beam:
+
+* the wavelengths :math:`\lambda`
+* the incidence angle :math:`\theta_\text{i}`
+* and the polarization, which can be given by a Jones or Stokes vector
+
+The evaluate method can be called, to start the calculation of the optical properties.
+To choose a Solver to be used in the calculation, the solver class is provided
+as an argument and an object will be created automatically.
+
+The experiment class is only needed in special cases an can be skipped by calling
+:meth:`elli.structure.Structure.evaluate`.
+"""
 import numpy as np
 import numpy.typing as npt
 
-from .solver4x4 import Solver4x4
-from .solver import Solver
 from .result import Result
+from .solver import Solver
+from .solver4x4 import Solver4x4
 
 
 class Experiment:
@@ -16,14 +32,21 @@ class Experiment:
     theta_i = None
     lbda = None
 
-    def __init__(self, structure: "Structure", lbda: npt.ArrayLike, theta_i: float, vector: npt.ArrayLike = [1, 0, 1, 0]) -> None:
+    def __init__(
+        self,
+        structure: "Structure",
+        lbda: npt.ArrayLike,
+        theta_i: float,
+        vector: npt.ArrayLike = None,
+    ) -> None:
         """Creates a virtual experiment to simulate the behavior of a structure.
-        
+
         Args:
             structure (Structure): Structure object to evaluate.
             lbda (npt.ArrayLike): Single value or array of wavelengths (in nm).
             theta_i (float): Incident angle (in degrees).
-            vector (npt.ArrayLike, optional): Jones or Stokes vector of incident light. Defaults to [1, 0, -1, 0].
+            vector (npt.ArrayLike, optional):
+                Jones or Stokes vector of incident light. Defaults to diagonal polarization ([1, 0, 1, 0]).
         """
         self.set_structure(structure)
         self.set_theta(theta_i)
@@ -57,23 +80,42 @@ class Experiment:
         Args:
             vector (npt.ArrayLike): Jones or Stokes vector of incident light.
         """
+        if vector is None:
+            vector = [1, 0, 1, 0]
+
         vector = np.asarray(vector)
 
         if vector.shape == (2,):
             self.jones_vector = vector
 
-            self.stokes_vector = np.array([
-                np.abs(self.jones_vector[0])**2 + np.abs(self.jones_vector[1])**2,
-                np.abs(self.jones_vector[0])**2 - np.abs(self.jones_vector[1])**2,
-                2 * np.real(self.jones_vector[0] * np.conjugate(self.jones_vector[1])),
-                -2 * np.imag(self.jones_vector[0] * np.conjugate(self.jones_vector[1]))])
+            self.stokes_vector = np.array(
+                [
+                    np.abs(self.jones_vector[0]) ** 2
+                    + np.abs(self.jones_vector[1]) ** 2,
+                    np.abs(self.jones_vector[0]) ** 2
+                    - np.abs(self.jones_vector[1]) ** 2,
+                    2
+                    * np.real(
+                        self.jones_vector[0] * np.conjugate(self.jones_vector[1])
+                    ),
+                    -2
+                    * np.imag(
+                        self.jones_vector[0] * np.conjugate(self.jones_vector[1])
+                    ),
+                ]
+            )
 
         elif vector.shape == (4,):
             self.stokes_vector = vector
 
-            p = np.sqrt(self.stokes_vector[1]**2 +
-                        self.stokes_vector[2]**2 +
-                        self.stokes_vector[3]**2) / self.stokes_vector[0]
+            p = (
+                np.sqrt(
+                    self.stokes_vector[1] ** 2
+                    + self.stokes_vector[2] ** 2
+                    + self.stokes_vector[3] ** 2
+                )
+                / self.stokes_vector[0]
+            )
             Q = self.stokes_vector[1] / (self.stokes_vector[0] * p)
             U = self.stokes_vector[2] / (self.stokes_vector[0] * p)
             V = self.stokes_vector[3] / (self.stokes_vector[0] * p)
@@ -116,8 +158,5 @@ class Experiment:
         Returns:
             Result: Result of the experiment.
         """
-        if solver_kwargs == {}:
-            solv = solver(self)
-        else:
-            solv = solver(self, **solver_kwargs)
+        solv = solver(self, **solver_kwargs)
         return solv.calculate()
