@@ -1,5 +1,5 @@
 # Encoding: utf-8
+from .dispersions import ConstantRefractiveIndex
 from .materials import IsotropicMaterial
-from .dispersions.dispersions import ConstantRefractiveIndex, EpsilonInf
 
 AIR = IsotropicMaterial(ConstantRefractiveIndex(n=1))
