@@ -1,11 +1,13 @@
 """Tests for a TiO2/SiO2/Si reference layer"""
 from __future__ import unicode_literals
-from distutils import dir_util
+
 import os
-import numpy as np
-from pytest import fixture
+from distutils import dir_util
+
 import elli
+import numpy as np
 from elli.fitting import ParamsHist
+from pytest import fixture
 
 
 @fixture
@@ -27,14 +29,14 @@ def datadir(tmpdir, request):
 @fixture
 def meas_data(datadir):
     """Fixture for getting the reference measurement data from the file."""
-    return elli.SpectraRay.read_rho(datadir.join("TiO2_400cycles.txt")).loc[400:800]
+    return elli.read_spectraray_rho(datadir.join("TiO2_400cycles.txt")).loc[400:800]
 
 
 @fixture
 def si_dispersion(datadir):
     """Fixture to load the silicon dispersion from file."""
-    sr = elli.SpectraRay(datadir)
-    silicon = elli.IsotropicMaterial(sr.loadDispersionTable(f"{os.sep}Si_Aspnes.mat"))
+    sr = elli.TableSpectraRay(datadir)
+    silicon = elli.IsotropicMaterial(sr.load_dispersion_table(f"{os.sep}Si_Aspnes.mat"))
 
     return silicon
 
@@ -110,22 +112,7 @@ class TestTiO2:
 
         assert TestTiO2.chisqr(meas_data, sim_data) < 0.0456
 
-    def test_solver4x4_torch(self, si_dispersion, meas_data):
-        """The solver4x4 with torch propagator is within chi square accuracy"""
-        sim_data = (
-            elli.Structure(elli.AIR, self.Layer, si_dispersion)
-            .evaluate(
-                meas_data.index,
-                70,
-                solver=elli.Solver4x4,
-                propagator=elli.PropagatorExpmTorch(),
-            )
-            .rho
-        )
-
-        assert TestTiO2.chisqr(meas_data, sim_data) < 0.0456
-
-    def test_solver4x4_scipy(self, si_dispersion, meas_data):
+    def test_solver4x4_expm(self, si_dispersion, meas_data):
         """The solver4x4 with scipy propagator is within chi square accuracy"""
         sim_data = (
             elli.Structure(elli.AIR, self.Layer, si_dispersion)
@@ -133,7 +120,7 @@ class TestTiO2:
                 meas_data.index,
                 70,
                 solver=elli.Solver4x4,
-                propagator=elli.PropagatorExpmScipy(),
+                propagator=elli.PropagatorExpm(),
             )
             .rho
         )
