@@ -1,8 +1,8 @@
 #!/usr/bin/python
 # encoding: utf-8
 
-import numpy as np
 import elli
+import numpy as np
 from scipy.constants import pi
 
 
@@ -47,8 +47,8 @@ class TestBragg:
     n.shape = (-1, 1)
 
     d = np.ones(N + 1)
-    d[1::2] = L_TiO2.d  #  d[0] is not used
-    d[2::2] = L_SiO2.d
+    d[1::2] = L_TiO2.thickness  #  d[0] is not used
+    d[2::2] = L_SiO2.thickness
 
     (lbda1, lbda2) = (1100, 2500)
     lbda_list = np.linspace(lbda1, lbda2, 200)
@@ -57,7 +57,7 @@ class TestBragg:
         """Returns the reflection coefficient in amplitude"""
         Kx = self.n[0] * np.sin(incidence_angle)
         sinPhi = Kx / self.n
-        kz = 2 * pi / self.lbda_list * np.sqrt(self.n ** 2 - Kx ** 2)
+        kz = 2 * pi / self.lbda_list * np.sqrt(self.n**2 - Kx**2)
 
         # Reflexion coefficient r_{k,k+1} for a single interface
         #    polarisation s:
@@ -110,13 +110,13 @@ class TestBragg:
         np.testing.assert_array_almost_equal(R_ss, R_th_ss, decimal=1)
         np.testing.assert_array_almost_equal(R_pp, R_th_pp, decimal=1)
 
-    def test_normal_incidence_4x4_scipy(self):
+    def test_normal_incidence_4x4_expm(self):
         data = self.s.evaluate(self.lbda_list, 0)
         R_ss_0 = data.R_ss
         R_th_ss_0 = (np.abs(self.ReflectionCoeff(0, "s"))) ** 2  # Phi_i = 0
         np.testing.assert_allclose(R_ss_0, R_th_ss_0, 1e-10, 0)
 
-    def test_angle_4x4_scipy(self):
+    def test_angle_4x4_expm(self):
         R_th_ss = (np.abs(self.ReflectionCoeff(pi / 4, "s"))) ** 2  # Phi_i = pi/4
         R_th_pp = (np.abs(self.ReflectionCoeff(pi / 4, "p"))) ** 2
 
@@ -159,43 +159,6 @@ class TestBragg:
         np.testing.assert_array_almost_equal(R_ss, R_th_ss, decimal=1)
         np.testing.assert_array_almost_equal(R_pp, R_th_pp, decimal=1)
 
-    def test_normal_incidence_4x4_torch(self):
-        data = self.s.evaluate(
-            self.lbda_list,
-            0,
-            solver=elli.Solver4x4,
-            propagator=elli.PropagatorExpmTorch(),
-        )
-        R_ss_0 = data.R_ss
-        R_th_ss_0 = (np.abs(self.ReflectionCoeff(0, "s"))) ** 2  # Phi_i = 0
-        np.testing.assert_allclose(R_ss_0, R_th_ss_0, 1e-10, 0)
-
-    def test_angle_4x4_torch(self):
-        R_th_ss = (np.abs(self.ReflectionCoeff(pi / 4, "s"))) ** 2  # Phi_i = pi/4
-        R_th_pp = (np.abs(self.ReflectionCoeff(pi / 4, "p"))) ** 2
-
-        # Incidence angle Phi_i = 0, 's' polarization
-
-        # Incidence angle Phi_i = pi/4, 's' and 'p' polarizations
-        data2 = self.s.evaluate(
-            self.lbda_list,
-            np.rad2deg(pi / 4),
-            solver=elli.Solver4x4,
-            propagator=elli.PropagatorExpmTorch(),
-        )
-
-        R_ss = data2.R_ss
-        R_pp = data2.R_pp
-
-        np.testing.assert_array_almost_equal(R_ss, R_th_ss, decimal=1)
-        np.testing.assert_array_almost_equal(R_pp, R_th_pp, decimal=1)
-
-    def test_normal_incidence_2x2(self):
-        data = self.s.evaluate(self.lbda_list, 0, solver=elli.Solver2x2)
-        R_ss_0 = data.R_ss
-        R_th_ss_0 = (np.abs(self.ReflectionCoeff(0, "s"))) ** 2  # Phi_i = 0
-        np.testing.assert_allclose(R_ss_0, R_th_ss_0, 1e-10, 0)
-
     def test_angle_2x2(self):
         R_th_ss = (np.abs(self.ReflectionCoeff(pi / 4, "s"))) ** 2  # Phi_i = pi/4
         R_th_pp = (np.abs(self.ReflectionCoeff(pi / 4, "p"))) ** 2
