@@ -1,8 +1,8 @@
 #!/usr/bin/python
 # encoding: utf-8
 
-import numpy as np
 import elli
+import numpy as np
 from scipy.constants import pi
 
 
@@ -43,7 +43,7 @@ class TestTirThickness:
 
     # Wave vector:
     kz_f = n_f * k0 * np.cos(Phi_i)
-    kz_s = k0 * np.sqrt(complex(n_s ** 2 - Kx ** 2))
+    kz_s = k0 * np.sqrt(complex(n_s**2 - Kx**2))
     kz_b = n_b * k0 * np.cos(Phi_b)
 
     # Amplitude coefficient polarisation s:
@@ -53,8 +53,8 @@ class TestTirThickness:
     t_bs_s = 1 + r_bs_s
 
     # Amplitude coefficient polarisation p:
-    r_sf_p = (kz_f * n_s ** 2 - kz_s * n_f ** 2) / (kz_s * n_f ** 2 + kz_f * n_s ** 2)
-    r_bs_p = (kz_s * n_b ** 2 - kz_b * n_s ** 2) / (kz_s * n_b ** 2 + kz_b * n_s ** 2)
+    r_sf_p = (kz_f * n_s**2 - kz_s * n_f**2) / (kz_s * n_f**2 + kz_f * n_s**2)
+    r_bs_p = (kz_s * n_b**2 - kz_b * n_s**2) / (kz_s * n_b**2 + kz_b * n_s**2)
     t_sf_p = np.cos(Phi_i) * (1 - r_sf_p) / np.cos(Phi_s)
     t_bs_p = np.cos(Phi_s) * (1 - r_bs_p) / np.cos(Phi_b)
 
@@ -93,7 +93,7 @@ class TestTirThickness:
     T_th_s = t2_th_s * correction
     T_th_p = t2_th_p * correction
 
-    def test_tir_thickness_4x4_scipy(self):
+    def test_tir_thickness_4x4_expm(self):
         data = elli.ResultList(
             [s.evaluate(self.lbda, np.rad2deg(self.Phi_i)) for s in self.structures]
         )
@@ -141,34 +141,6 @@ class TestTirThickness:
         np.testing.assert_allclose(t2_p, self.t2_th_p)
         np.testing.assert_allclose(t2_s, self.t2_th_s)
 
-    def test_tir_thickness_4x4_torch(self):
-        data = elli.ResultList(
-            [
-                s.evaluate(
-                    self.lbda,
-                    np.rad2deg(self.Phi_i),
-                    solver=elli.Solver4x4,
-                    propagator=elli.PropagatorExpmTorch(),
-                )
-                for s in self.structures
-            ]
-        )
-
-        # Extraction of the transmission and reflexion coefficients
-        R_p = data.R_pp
-        R_s = data.R_ss
-        T_p = data.T_pp
-        T_s = data.T_ss
-        t2_p = np.abs(data.t_pp) ** 2  # Before power correction
-        t2_s = np.abs(data.t_ss) ** 2
-
-        np.testing.assert_allclose(R_p, self.R_th_p)
-        np.testing.assert_allclose(R_s, self.R_th_s)
-        np.testing.assert_allclose(T_p, self.T_th_p)
-        np.testing.assert_allclose(T_s, self.T_th_s)
-        np.testing.assert_allclose(t2_p, self.t2_th_p)
-        np.testing.assert_allclose(t2_s, self.t2_th_s)
-
     def test_tir_thickness_2x2(self):
         data = elli.ResultList(
             [
@@ -230,7 +202,7 @@ class TestTirAngle:
 
     # Wave vector:
     kz_f = n_f * k0 * np.cos((Phi_list.astype(complex)))
-    kz_s = k0 * np.sqrt((-(Kx ** 2 - n_s ** 2)).astype(complex))
+    kz_s = k0 * np.sqrt((-(Kx**2 - n_s**2)).astype(complex))
     kz_b = n_b * k0 * np.cos(Phi_b)
 
     # Amplitude coefficient for 's' polarisation:
@@ -240,8 +212,8 @@ class TestTirAngle:
     t_bs_s = 1 + r_bs_s
 
     # Amplitude coefficient for 'p' polarisation:
-    r_sf_p = (kz_f * n_s ** 2 - kz_s * n_f ** 2) / (kz_s * n_f ** 2 + kz_f * n_s ** 2)
-    r_bs_p = (kz_s * n_b ** 2 - kz_b * n_s ** 2) / (kz_s * n_b ** 2 + kz_b * n_s ** 2)
+    r_sf_p = (kz_f * n_s**2 - kz_s * n_f**2) / (kz_s * n_f**2 + kz_f * n_s**2)
+    r_bs_p = (kz_s * n_b**2 - kz_b * n_s**2) / (kz_s * n_b**2 + kz_b * n_s**2)
     t_sf_p = np.cos((Phi_list.astype(complex))) * (1 - r_sf_p) / np.cos(Phi_s)
     t_bs_p = np.cos(Phi_s) * (1 - r_bs_p) / np.cos(Phi_b)
 
@@ -280,7 +252,7 @@ class TestTirAngle:
     T_th_s = t2_th_s * correction
     T_th_p = t2_th_p * correction
 
-    def test_tir_angle_4x4_scipy(self):
+    def test_tir_angle_4x4_expm(self):
         data = elli.ResultList(
             [self.s.evaluate(self.lbda, np.rad2deg(Phi_i)) for Phi_i in self.Phi_list]
         )
@@ -328,34 +300,6 @@ class TestTirAngle:
         np.testing.assert_allclose(t2_p, self.t2_th_p)
         np.testing.assert_allclose(t2_s, self.t2_th_s)
 
-    def test_tir_angle_4x4_torch(self):
-        data = elli.ResultList(
-            [
-                self.s.evaluate(
-                    self.lbda,
-                    np.rad2deg(Phi_i),
-                    solver=elli.Solver4x4,
-                    propagator=elli.PropagatorExpmTorch(),
-                )
-                for Phi_i in self.Phi_list
-            ]
-        )
-
-        # Extraction of the transmission and reflexion coefficients
-        R_p = data.R_pp
-        R_s = data.R_ss
-        T_p = data.T_pp
-        T_s = data.T_ss
-        t2_p = np.abs(data.t_pp) ** 2  # Before power correction
-        t2_s = np.abs(data.t_ss) ** 2
-
-        np.testing.assert_allclose(R_p, self.R_th_p)
-        np.testing.assert_allclose(R_s, self.R_th_s)
-        np.testing.assert_allclose(T_p, self.T_th_p)
-        np.testing.assert_allclose(T_s, self.T_th_s)
-        np.testing.assert_allclose(t2_p, self.t2_th_p)
-        np.testing.assert_allclose(t2_s, self.t2_th_s)
-
     def test_tir_angle_2x2(self):
         data = elli.ResultList(
             [
